@@ -4,7 +4,7 @@ package CouchDB::Client;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use JSON::Any       qw(XS JSON DWIW);
 use LWP::UserAgent  qw();
@@ -195,11 +195,12 @@ Gets a path and returns the complete URI.
 =head1 AUTHOR
 
 Robin Berjon, <robin @t berjon d.t com>
+Maverick Edwards (current maintainer) <medwards @t nasba d.t org>
 
 =head1 BUGS 
 
 Please report any bugs or feature requests to bug-couchdb-client at rt.cpan.org, or through the
-web interface at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CouchDb-Client.
+web interface at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=CouchDB-Client.
 
 =head1 COPYRIGHT & LICENSE 
 
